/* timer-test.c -- Test of timer and LCD
   Copyright 2000 Free Software Foundation, Inc.
   Written by Stephane Carrez (stcarrez@worldnet.fr)

This file is part of EBCS.

EBCS is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

EBCS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with EBCS; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include <sys/param.h>
#include <sys/locks.h>
#include <sys/interrupts.h>
#include <ebcs.h>
#include <lcd.h>
#include <sys/timer.h>
#include <sys/spi.h>
#include <sys/event.h>
#include <sci.h>

unsigned long idle_count;
unsigned long pidle_count;
unsigned long cnt_count;
unsigned char ms_dt;

void
ms_timeout (struct timer* t)
{
  sci_putc ('\b');
  sci_putc ("/-\\|"[ms_dt]);
  ms_dt = (ms_dt + 1) % 4;

  t->handler = ms_timeout;
  t->timeout = 300;
  t->flags = 0;
  timer_insert (t);
}

void
second_timeout (struct timer* t)
{
  struct timeval tv;
  unsigned long seconds;
  unsigned short hours, mins;
  unsigned long nus;
  char buf[32];
  unsigned long cnt;
  long dt;
  
  cnt = idle_count * 20;
  pidle_count += cnt;
  cnt_count++;
  idle_count = 0;
  cnt = (cnt * 1000L) / (2000000L * 2);
  if (cnt >= 1000)
    cnt = 999;

  buf[0] = '\r';
  buf[1] = '0' + (cnt / 100);
  buf[2] = '0' + ((cnt % 100) / 10);
  buf[3] = '.';
  buf[4] = '0' + ((cnt % 100) % 10);
  buf[5] = ' ';
  sci_write (buf, 6);

  cnt = pidle_count / cnt_count;
  if (cnt_count > 20)
    {
      cnt_count --;
      pidle_count -= cnt;
    }
  cnt = (cnt * 1000L) / (2000000L * 2);
  if (cnt >= 1000)
    cnt = 999;

  buf[0] = ' ';
  buf[1] = '0' + (cnt / 100);
  buf[2] = '0' + ((cnt % 100) / 10);
  buf[3] = '.';
  buf[4] = '0' + ((cnt % 100) % 10);
  buf[5] = ' ';
  sci_write (buf, 6);
  timer_gettime (&tv);
  seconds = tv.tv_sec;
  hours = (unsigned short) (seconds / 3600L);
  hours = hours % 24;
  mins = (unsigned short) (seconds % 3600L);
  seconds = (unsigned long) (mins % 60);
  mins = mins / 60;
  nus = tv.tv_usec / 100000L;
  buf[0] = '0' + (hours / 10);
  buf[1] = '0' + (hours % 10);
  buf[2] = ':';
  buf[3] = '0' + (mins / 10);
  buf[4] = '0' + (mins % 10);
  buf[5] = ':';
  buf[6] = '0' + (seconds / 10);
  buf[7] = '0' + (seconds % 10);
  buf[8] = '.';
  buf[9] = '0' + nus;
  buf[10] = ' ';
  buf[11] = 0;
  sci_write (buf, 11);

  timer_gettime (&tv);
  dt = 1000000L - tv.tv_usec;
  timer_create (t, dt / 1000, second_timeout);
}

#define EVENT_QUEUE_SIZE (16)
#define SPI_QUEUE_SIZE (16)

static event event_queue[EVENT_QUEUE_SIZE];

int
main()
{
  struct timer sec_timer;
  unsigned short mask;
  char sci_buffer[64];
  unsigned long *cnt;
  
  sci_initialize (0x33, sci_buffer, sizeof (sci_buffer));

  mask = lock ();
  timer_initialize ();
  event_initialize (event_queue, EVENT_QUEUE_SIZE);
  spi_initialize (M6811_MSTR | M6811_CPOL | M6811_CPHA | 3);
  restore (mask);

  idle_count = 0;
  timer_create (&sec_timer, 1000, second_timeout);

  cnt = &idle_count;
  while (1)
    {
      cnt[0] ++;
    }
}
